@@ -40,6 +40,7 @@ class MyPlots
         t.def_figure("Greens") { greens }
         t.def_figure("Blues_axes_1") { blues_axes_1 }
         t.def_figure("Blues_axes_2") { blues_axes_2 }
+        t.def_figure("Blues_without_padding") { blues_without_padding }
         t.def_figure("Log_Reds") { log_reds }
         t.def_figure("Side_by_Side") { side_by_side }
         t.def_figure("Two_Ys") { two_yaxes }
@@ -50,8 +51,7 @@ class MyPlots
         t.def_figure("Legend_Inside") { legend_inside }
         t.def_figure("Legend_Outside") { legend_outside }
         t.def_figure("Legend_Inside_with_Background") { legend_inside_with_background }
-        t.def_figure("Legend_Inside_with_Background_using_legend_background") 
-            { legend_inside_with_background_using_legend_background }
+        t.def_figure("Legend_Inside_with_Background_using_legend_background") { legend_inside_with_background_using_legend_background }
         t.def_figure("Inset") { inset }
         t.def_figure("French_Decimal_Separator") { french_decimal_separator }
         t.def_figure("Column_Triplets") { column_triplets }
@@ -72,8 +72,9 @@ class MyPlots
         t.def_figure("Arrows") { arrows }
         t.def_figure("Special_Y") { special_y }
         t.def_figure("Sampled_Splines") { sampled_splines }
+        t.def_figure("Sampled_pm_cubics") { sampled_pm_cubics }
         t.def_figure("Steps") { steps }
-        t.def_figure("Splines") { splines }
+        t.def_figure("Bezier") { bezier }
         t.def_figure("Sampled_Data") { sampled_data }
         t.def_figure("Sampled_with_grid") { sampled_with_grid }
         t.def_figure("Contours") { samples_with_contours }
@@ -183,6 +184,13 @@ EOD
             t.show_grid(opts)
             t.show_polyline(xs,ys,Blue) }
     end
+    
+    def blues_without_padding
+      p t.default_frame_right
+      t.default_frame_right = 1.0
+      p t.default_frame_right
+      blues
+    end
 
     def blues_far_off(opts={})
         opts = {
@@ -873,6 +881,33 @@ EOD
                 'marker' => Bullet, 'scale' => 0.6, 'color' => Red);
         end
     end
+
+    
+    def sampled_pm_cubics
+        t.do_box_labels("Sampled pm cubics", "Position", "Average Count")
+        xs = Dvector[ 1.0, 2.0, 5.0, 6.0, 7.0, 8.0, 10.0, 13.0, 17.0 ]
+        ys = Dvector[ 3.0, 3.7, 3.9, 4.2, 5.7, 6.6,  7.1,  6.7,  4.5 ]
+        data_pts = xs.size
+        csdata_interpolant = Dvector.create_pm_cubic_interpolant(xs, ys)
+        smooth_pts = 4*(data_pts-1) + 1
+        dx = (xs[data_pts-1] - xs[0])/(smooth_pts-1)
+        pm_xs = Dvector.new(smooth_pts) { |i| i*dx + xs[0] }
+        pm_ys = pm_xs.dup
+        pm_ys.length.times {|i| pm_ys[i] = 
+                Dvector.pm_cubic_interpolate(pm_xs[i], csdata_interpolant) }
+        t.show_plot([-1, 19, 8, 2]) do
+            t.fill_color = FloralWhite
+            t.fill_frame
+            t.stroke_color = Blue
+            t.append_points_to_path(pm_xs, pm_ys)
+            t.stroke
+            t.show_marker('Xs' => pm_xs, 'Ys' => pm_ys,
+                'marker' => Bullet, 'scale' => 0.4, 'color' => Green);
+            t.show_marker('Xs' => xs, 'Ys' => ys,
+                'marker' => Bullet, 'scale' => 0.6, 'color' => Red);
+        end
+    end
+    
     
     def steps
         t.do_box_labels("Steps", "Position", "Average Count")
@@ -897,8 +932,8 @@ EOD
         end
     end
     
-    def splines # append bezier curves
-        t.do_box_labels("Splines", "Position", "Average Count")
+    def bezier # append bezier curves
+        t.do_box_labels("bezier curves", "Position", "Average Count")
         xs = Dvector[ 1.0, 2.0, 5.0, 6.0, 7.0, 8.0, 10.0, 13.0, 17.0 ]
         ys = Dvector[ 3.0, 3.7, 3.9, 4.2, 5.7, 6.6,  7.1,  6.7,  4.5 ]
         scale = Dvector[ 0.6, 0.9 ]
@@ -917,6 +952,7 @@ EOD
         end
     end
     
+    
     def sampled_image(title, colormap = nil)
         t.do_box_labels(title, 'Log Density', 'Log Temperature')
         data = get_press_image
@@ -1076,12 +1112,15 @@ EOD
     # This plot is to demonstrate the new power of #show_axis.
     def axes_fun
       t.do_box_labels("Funny axes", "", "")
+      t.xaxis_labels_color = [0.3,0.5,0.3]
+      t.yaxis_labels_color = [0.7,0.2,0.4]
       t.show_plot([-1, 19, 8, 2]) do
         spec = {
           'from' => [3,3],
           'to' => [3,7],
           'ticks_outside' => true,
           'ticks_inside' => false,
+          'log' => true
         }
         t.show_axis(spec)
         p t.axis_information(RIGHT)
@@ -1091,7 +1130,8 @@ EOD
           'ticks_outside' => true,
           'ticks_inside' => false,
           'major_ticks' => [4,6],
-          'labels' => ["$a$", "$b$"]
+          'labels' => ["$a$", "$b$"],
+          'color' => [0,0.8,0.3]
         }
         t.show_axis(spec2)
         spec3 = {
@@ -1100,7 +1140,9 @@ EOD
           'ticks_outside' => true,
           'ticks_inside' => false,
           'shift' => 1.3,
-          'labels' => ["$a$", "$b$", 'c', 'd', 'e']
+          'labels' => ["$a$", "$b$", 'c', 'd', 'e'],
+          'stroke_color' => [0.2,0.4,0.7],
+          'labels_color' => [0.3,0.2,0.4]
         }
         t.show_axis(spec3)
       end
