@@ -33,12 +33,43 @@ module Dobjects
     #
     #  e = MathEvaluator.new("x*y", "x,y")
     #  e.compute(1,2)         -> 2
+    #
+    # If an exception arises, NaN is returned. Note that compilation
+    # problems will be caught before ;-)...
     def compute(*args)
+      begin
+        return compute_unsafe(*args)
+      rescue
+        return 0.0/0.0
+      end
+    end
+
+    # This function does the actual evaluation with the blocks
+    # given.
+    #
+    #  e = MathEvaluator.new("x*y", "x,y")
+    #  e.compute(1,2)         -> 2
+    # 
+    # No care is taken to intercept exceptions.
+    def compute_unsafe(*args)
       return @block.call(*args)
     end
+
   end
 
   class Dvector
+  
+    # thanks to Dave MacMahon for from_na and to_na
+    # Create a Dvector from an NArray.
+    def Dvector.from_na(na)
+      _load([1, na.length, na.to_s].pack('CIa*'))
+    end
+
+    # Create an NArray with the same length and contents as +self+.
+    def to_na
+      ::NArray.to_na(_dump(nil)[5..-1], ::NArray::DFLOAT)
+    end
+    
       
     def to_dvector
       self
