@@ -569,6 +569,7 @@ void Init_FigureMaker(void) {
    attr_accessors(xaxis_type)
    attr_accessors(xaxis_line_width)
    attr_accessors(xaxis_stroke_color)
+   attr_accessors(xaxis_labels_color)
    attr_accessors(xaxis_major_tick_width)
    attr_accessors(xaxis_minor_tick_width)
    attr_accessors(xaxis_major_tick_length)
@@ -600,6 +601,7 @@ void Init_FigureMaker(void) {
    attr_accessors(yaxis_type)
    attr_accessors(yaxis_line_width)
    attr_accessors(yaxis_stroke_color)
+   attr_accessors(yaxis_labels_color)
    attr_accessors(yaxis_major_tick_width)
    attr_accessors(yaxis_minor_tick_width)
    attr_accessors(yaxis_major_tick_length)
