@@ -34,7 +34,7 @@ class FigureMaker
 
     # This URL will contain tioga-(...) when it is exported from the
     # SVN repository. This is where we'll look for version information.
-    SVN_URL = '$HeadURL: svn+ssh://rubyforge.org/var/svn/tioga/tags/tioga/Tioga%201.10/split/Tioga/lib/FigMkr.rb $'
+    SVN_URL = '$HeadURL: svn+ssh://rubyforge.org/var/svn/tioga/tags/tioga/Tioga%201.11/split/Tioga/lib/FigMkr.rb $'
 
     TIOGA_VERSION = if SVN_URL =~ /tags\/tioga\/Tioga%20([^\/]+)/
                        $1
@@ -1806,7 +1806,8 @@ class FigureMaker
             fill_color = get_if_given_else_use_default_dict(dict, 'fill_color', @marker_defaults)
             stroke_color = get_if_given_else_use_default_dict(dict, 'stroke_color', @marker_defaults)
         else
-            fill_color = stroke_color = color
+          stroke_color = dict['stroke_color'] || color
+          fill_color = dict['fill_color'] || color
         end
         font = dict['font']
         mode = alt_names(dict, 'mode', 'rendering_mode')
