@@ -326,10 +326,11 @@ class TiogaUI
     $figures_font = 'system 12'
 =end
     
-    tiogainit_name = ENV['HOME'] + '/.tiogainit'
-    if File.exist?(tiogainit_name)
-      load(tiogainit_name)
+    tiogainit_names = %w[ .tiogarc .tiogainit ].map do |f|
+      File.join(ENV['HOME'], f)
     end
+    tiogainit_name = tiogainit_names.find {|f| test ?e, f}
+    load(tiogainit_name) unless tiogainit_name.nil?
     
     @pdf_name = nil
     @have_loaded = false    
@@ -443,8 +444,8 @@ class TiogaUI
         return
       end
       make_portfolio(true, parse_figs($tioga_args[argnum]))
-    else # unrecognized command
-      show_help(filename,cmd)
+    #else # unrecognized command
+    #  show_help(filename,cmd)
     end
   rescue
   end
