@@ -29,14 +29,6 @@
 
 /* 
    Here is my (Vincent) big TODO-list for the axes stuff:
-   * provide a way to reliably get the location from major/minor
-     ticks for a given axis, so users can build lines/grids that build on
-     top of that (or rather under it ;-)...)
-     -> this is partly done, as you can now get the major ticks position.
-   * let the users choose between the current way to pick up ticks position
-     and another, such as the one I'm using in SciYAG, which seems to give
-     results that are more according to my expectations.
-
    * BUG fix: apparently, two calls to the axes stuff do no return the
      same thing, so I'll need to have a careful look at that
  */
@@ -45,9 +37,17 @@ typedef struct {
    int type;
    int other_axis_type;
    double line_width;
+
+   /* Stroke color... */
    double stroke_color_R;
    double stroke_color_G;
    double stroke_color_B;
+
+   /* Tick labels color */
+   double labels_color_R;
+   double labels_color_G;
+   double labels_color_B;
+
    double major_tick_width; // same units as line_width
    double minor_tick_width; // same units as line_width
    double major_tick_length; // in units of numeric label char heights
@@ -131,6 +131,11 @@ static void Get_xaxis_Specs(OBJ_PTR fmkr, FM *p, PlotAxis *s, int *ierr)
    s->stroke_color_R = p->xaxis_stroke_color_R; // for axis line and tick marks
    s->stroke_color_G = p->xaxis_stroke_color_G;
    s->stroke_color_B = p->xaxis_stroke_color_B;
+
+   s->labels_color_R = p->xaxis_labels_color_R; // for axis line and tick marks
+   s->labels_color_G = p->xaxis_labels_color_G;
+   s->labels_color_B = p->xaxis_labels_color_B;
+
    s->major_tick_width = p->xaxis_major_tick_width; // same units as line_width
    s->minor_tick_width = p->xaxis_minor_tick_width; // same units as line_width
    s->major_tick_length = p->xaxis_major_tick_length; // in units of numeric label char heights
@@ -167,9 +172,15 @@ static void Get_yaxis_Specs(OBJ_PTR fmkr, FM *p, PlotAxis *s, int *ierr)
    s->type = p->yaxis_type;
    s->other_axis_type = p->xaxis_type;
    s->line_width = p->yaxis_line_width; // for axis line
+
    s->stroke_color_R = p->yaxis_stroke_color_R; // for axis line and tick marks
    s->stroke_color_G = p->yaxis_stroke_color_G;
    s->stroke_color_B = p->yaxis_stroke_color_B;
+
+   s->labels_color_R = p->yaxis_labels_color_R; // for axis line and tick marks
+   s->labels_color_G = p->yaxis_labels_color_G;
+   s->labels_color_B = p->yaxis_labels_color_B;
+
    s->major_tick_width = p->yaxis_major_tick_width; // same units as line_width
    s->minor_tick_width = p->yaxis_minor_tick_width; // same units as line_width
    s->major_tick_length = p->yaxis_major_tick_length; // in units of numeric label char heights
@@ -840,6 +851,13 @@ static void draw_minor_ticks(OBJ_PTR fmkr, FM *p, PlotAxis *s, int *ierr)
 static void show_numeric_label(OBJ_PTR fmkr, FM *p, PlotAxis *s, 
    char *text, int location, double position, double shift, int *ierr)
 { 
+   /* We need a buffer to implement the color */
+   long len = strlen(text) + 100; /* Should be enough overhead ! */
+   char * buffer = ALLOC_N_char(len);
+   snprintf(buffer, len, "\\textcolor[rgb]{%0.2f,%0.2f,%0.2f}{%s}",
+	    s->labels_color_R, s->labels_color_G, s->labels_color_B,
+	    text);
+	    
    if(location == AXIS_FREE_LOCATION) {
       /* We convert the tick position into frame position */
       double x,y, ft_ht = p->default_text_scale * 
@@ -861,7 +879,7 @@ static void show_numeric_label(OBJ_PTR fmkr, FM *p, PlotAxis *s,
 						 ft_ht * ENLARGE * shift);
       }
 
-      c_show_rotated_label(fmkr, p, text, x, y, 
+      c_show_rotated_label(fmkr, p, buffer, x, y, 
 			   s->numeric_label_scale, 
 			   s->numeric_label_angle + angle, 
 			   s->numeric_label_justification, 
@@ -871,9 +889,10 @@ static void show_numeric_label(OBJ_PTR fmkr, FM *p, PlotAxis *s,
    else {
       // position is in figure coords and must be converted to frame coords
       double pos = ((!s->reversed)? (position - s->axis_min) : (s->axis_max - position)) / s->length;
-      c_show_rotated_text(fmkr, p, text, location, shift, pos, 
+      c_show_rotated_text(fmkr, p, buffer, location, shift, pos, 
 			  s->numeric_label_scale, s->numeric_label_angle, s->numeric_label_justification, s->numeric_label_alignment, OBJ_NIL, ierr);
    }
+   free(buffer);
 }
 
 static void draw_numeric_labels(OBJ_PTR fmkr, FM *p, int location, PlotAxis *s, int *ierr)
@@ -1177,6 +1196,40 @@ static int prepare_dict_PlotAxis(OBJ_PTR fmkr, FM *p,
    if(Hash_Has_Key(axis_spec, "minor_tick_length"))
       axis->minor_tick_length = Hash_Get_Double(axis_spec, "minor_tick_length");
 
+   /* Stroke color */
+   if(Hash_Has_Key(axis_spec, "stroke_color") || 
+      Hash_Has_Key(axis_spec, "color")) {
+      OBJ_PTR color = (Hash_Has_Key(axis_spec, "stroke_color") ? 
+		       Hash_Get_Obj(axis_spec, "stroke_color") :
+		       Hash_Get_Obj(axis_spec, "color") );
+      int err;
+      axis->stroke_color_R = Array_Entry_double(color, 0, &err);
+      axis->stroke_color_G = Array_Entry_double(color, 1, &err);
+      axis->stroke_color_B = Array_Entry_double(color, 2, &err);
+   }
+
+   /* Labels color */
+   if(Hash_Has_Key(axis_spec, "labels_color") || 
+      Hash_Has_Key(axis_spec, "color")) {
+      OBJ_PTR color = (Hash_Has_Key(axis_spec, "labels_color") ? 
+		       Hash_Get_Obj(axis_spec, "labels_color") :
+		       Hash_Get_Obj(axis_spec, "color") );
+      int err;
+      axis->labels_color_R = Array_Entry_double(color, 0, &err);
+      axis->labels_color_G = Array_Entry_double(color, 1, &err);
+      axis->labels_color_B = Array_Entry_double(color, 2, &err);
+   }
+
+   /* Log scale: */
+   if(Hash_Has_Key(axis_spec, "log")) {
+      OBJ_PTR val = Hash_Get_Obj(axis_spec, "log");
+      if(val == OBJ_NIL || val == OBJ_FALSE)
+	 axis->log_vals = 0;
+      else
+	 axis->log_vals = 1;
+   }
+   
+
    return 1;
 }
 
@@ -1202,7 +1255,8 @@ void c_show_axis_generic(OBJ_PTR fmkr, FM *p, OBJ_PTR axis_spec, int *ierr)
 /* 
    This function takes an axis specification (either integer or
    hash) and returns a hash containing the following keys:
-   * 'major' : position of all major ticks
+   * 'major_ticks' : position of all major ticks
+   * 'minor_ticks' : position of all major ticks
    * 'labels' : the names of all labels
    * 'vertical' : if the axis is vertical or horizontal
    * 'line_width' : the line width
@@ -1211,8 +1265,9 @@ void c_show_axis_generic(OBJ_PTR fmkr, FM *p, OBJ_PTR axis_spec, int *ierr)
    * 'scale', 'shift' and 'angle': the scale, shift and angle of numeric
      labels
    * 'x0', 'y0', 'x1', 'y1': the position of the axis in figure coordinates
-
- */
+   * 'stroke_color': the color to use for drawing lines.
+   * 'labels_color': the color to use for drawing tick labels.
+*/
 OBJ_PTR c_axis_get_information(OBJ_PTR fmkr, FM *p, OBJ_PTR axis_spec,
 			       int *ierr)
 {
@@ -1228,14 +1283,15 @@ OBJ_PTR c_axis_get_information(OBJ_PTR fmkr, FM *p, OBJ_PTR axis_spec,
    /* First, major ticks positions */
    prepare_axis_coordinates(fmkr, p, axis.location, &axis, ierr);
    compute_major_ticks(fmkr, p, &axis, ierr);
-   Hash_Set_Obj(hash, "major", Vector_New(axis.nmajors, axis.majors));
+   Hash_Set_Obj(hash, "major_ticks", Vector_New(axis.nmajors, axis.majors));
 
    /* Then, minor ticks positions */
    double * minor;
    long count;
+   OBJ_PTR color;
    minor = get_minor_ticks_location(fmkr, p, &axis, &count);
    if(minor) {
-      Hash_Set_Obj(hash, "minor", Vector_New(count, minor));
+      Hash_Set_Obj(hash, "minor_ticks", Vector_New(count, minor));
       free(minor);
    }
 
@@ -1268,6 +1324,25 @@ OBJ_PTR c_axis_get_information(OBJ_PTR fmkr, FM *p, OBJ_PTR axis_spec,
    Hash_Set_Double(hash, "y0", axis.y0);
    Hash_Set_Double(hash, "y1", axis.y1);
 
+   /* Log values */
+   Hash_Set_Obj(hash, "log", axis.log_vals ? OBJ_TRUE : OBJ_FALSE);
+
+   /* Stroke color */
+   color = Array_New(3);
+   Array_Store(color, 0, Float_New(axis.stroke_color_R),ierr);
+   Array_Store(color, 1, Float_New(axis.stroke_color_G),ierr);
+   Array_Store(color, 2, Float_New(axis.stroke_color_B),ierr);
+   Hash_Set_Obj(hash, "stroke_color", color);
+
+   /* Tick labels color */
+   color = Array_New(3);
+   Array_Store(color, 0, Float_New(axis.labels_color_R),ierr);
+   Array_Store(color, 1, Float_New(axis.labels_color_G),ierr);
+   Array_Store(color, 2, Float_New(axis.labels_color_B),ierr);
+   Hash_Set_Obj(hash, "labels_color", color);
+
+
+
    free_allocated_memory(&axis);
    return hash;
 }
